@@ -22,6 +22,7 @@ from tair.tairroaring import TrScanResult
 from tair.tairsearch import ScandocidResult
 from tair.tairstring import ExcasResult, ExgetResult
 from tair.tairts import Aggregation, TairTsSkeyItem
+from tair.tairvector import TairVectorIndex, TairVectorScanResult
 from tair.tairzset import TairZsetItem
 
 __all__ = [
@@ -54,4 +55,6 @@ __all__ = [
     "TairError",
     "TimeoutError",
     "WatchError",
+    "TairVectorScanResult",
+    "TairVectorIndex",
 ]
