@@ -1,11 +1,10 @@
 from typing import Mapping, Optional, Union
 
-from redis import ConnectionPool
-from redis.asyncio.client import Redis
+from redis.asyncio import ConnectionPool, Redis
 from redis.retry import Retry
 
+from tair.asyncio.pipeline import Pipeline
 from tair.commands import TairCommands, set_tair_response_callback
-from tair.pipeline import Pipeline
 
 
 class Tair(Redis, TairCommands):
@@ -81,9 +80,6 @@ class Tair(Redis, TairCommands):
         )
         set_tair_response_callback(self)
 
-    async def initialize(self):
-        await Redis.initialize(self)
-
     def pipeline(self, transaction: bool = True, shard_hint: Optional[str] = None):
         return Pipeline(
             self.connection_pool,
