@@ -1,5 +1,6 @@
 from typing import Dict, Iterable, List, Optional
 
+import tair
 from tair.typing import CommandsProtocol, EncodableT, KeyT, ResponseT
 
 
@@ -30,6 +31,12 @@ class TairSearchCommands(CommandsProtocol):
     def tft_getindex(self, index: KeyT) -> ResponseT:
         return self.execute_command("TFT.GETINDEX", index)
 
+    def tft_getindex_mappings(self, index: KeyT) -> ResponseT:
+        return self.execute_command("TFT.GETINDEX", index, "mappings")
+
+    def tft_getindex_settings(self, index: KeyT) -> ResponseT:
+        return self.execute_command("TFT.GETINDEX", index, "settings")
+
     def tft_adddoc(
         self,
         index: KeyT,
@@ -134,18 +141,41 @@ class TairSearchCommands(CommandsProtocol):
 
         return self.execute_command("TFT.SCANDOCID", *pieces)
 
-    def tft_deldoc(self, index: KeyT, doc_id: str, fields: Iterable[str]) -> ResponseT:
-        return self.execute_command("TFT.DELDOC", index, doc_id, *fields)
+    def tft_deldoc(self, index: KeyT, doc_id: Iterable[str]) -> ResponseT:
+        return self.execute_command("TFT.DELDOC", index, *doc_id)
 
     def tft_delall(self, index: KeyT) -> ResponseT:
         return self.execute_command("TFT.DELALL", index)
 
-    def tft_search(self, index: KeyT, query: str) -> ResponseT:
-        return self.execute_command("TFT.SEARCH", index, query)
+    def tft_search(self, index: KeyT, query: str, use_cache: bool = False) -> ResponseT:
+        pieces: List[EncodableT] = [index, query]
+        if use_cache:
+            pieces.append("use_cache")
+        return self.execute_command("TFT.SEARCH", *pieces)
 
     def tft_msearch(self, index_count: int, index: Iterable[KeyT], query: str) -> ResponseT:
         return self.execute_command("TFT.MSEARCH", index_count, *index, query)
 
+    def tft_analyzer(self, analyzer_name: str, text: str, index: Optional[KeyT] = None,
+                     show_time: Optional[bool] = False) -> ResponseT:
+        pieces: List[EncodableT] = [analyzer_name, text]
+        if index is not None:
+            pieces.append("INDEX")
+            pieces.append(index)
+        if show_time:
+            pieces.append("show_time")
+        target_nodes = None
+        if isinstance(self, tair.TairCluster):
+            if index is None:
+                target_nodes = 'random'
+            else:
+                target_nodes = self.nodes_manager.get_node_from_slot(self.keyslot(index))
+        return self.execute_command("TFT.ANALYZER", *pieces, target_nodes=target_nodes)
+
+    def tft_explaincost(self, index: KeyT, query: str) -> ResponseT:
+        pieces: List[EncodableT] = [index, query]
+        return self.execute_command("TFT.EXPLAINCOST", *pieces)
+
     def tft_addsug(self, index: KeyT, mapping: Dict[str, int]) -> ResponseT:
         pieces: List[EncodableT] = [index]
 
